@@ -4,9 +4,9 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+#our $VERSION = '0.01';
 
-BEGIN { require PNI::Node , @ISA = ( 'PNI::Node' ) }
+our @ISA = ( 'PNI::Node' );
 
 sub init {
     my $node = shift;
